=========
UK Boards
=========


.. image:: https://img.shields.io/pypi/v/uk_boards.svg
        :target: https://pypi.python.org/pypi/uk_boards

.. image:: https://img.shields.io/travis/spool/uk_boards.svg
        :target: https://travis-ci.org/spool/uk_boards

.. image:: https://readthedocs.org/projects/uk-boards/badge/?version=latest
        :target: https://uk-boards.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/spool/uk_boards/shield.svg
     :target: https://pyup.io/repos/github/spool/uk_boards/
     :alt: Updates

.. image:: https://codecov.io/gh/spool/uk_boards/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/spool/uk_boards


Query UK company and charity board networks.


* Free software: MIT License
* Documentation: https://uk-boards.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
